import { Ref, ComputedRef, UnwrapNestedRefs } from 'vue';
import { FolderRetrieve, FolderFile, FileRetrieve, File, FolderFolder, Favorite, FileContentTypeEnum, Folder, MiniPage } from '../../../../types/openapi';
import { RecentFile } from '../../../types/recentFiles.types';
import { ApiStore } from './api';
export type AppName = 'admin' | 'impact';
export type SelectorType = 'content' | 'assets' | 'external_links' | 'ai_images' | 'pexels_images' | 'theme' | `multimedia-selector-${string}`;
export type SelectedPage = {
    id: string;
    name?: string;
    file: {
        id: File['id'];
        name: File['name'];
    };
    page_index: number;
    permissions?: File['permissions'];
    thumbnail_url?: string;
    type: 'page';
};
export type SelectedFile = FolderFile & {
    type: 'file';
};
export type SelectedFolder = FolderFolder & {
    type: 'folder';
};
export type SelectedAsset = {
    id: File['id'];
    type: 'asset';
    content_extension?: File['content_extension'];
    thumbnail_url?: string;
    content_url?: string;
    file?: {
        id: File['id'];
        name: File['name'];
    };
    theme_meta?: {
        is_theme_logo?: boolean;
        theme_asset_index?: number;
    };
};
export type SelectedExternalLink = {
    id: string;
    url: string;
    thumbnail_url?: string;
    type: 'external_link';
    content_type: 'video' | 'image';
    from: 'custom' | 'pexels' | 'unsplash' | 'ai';
    theme_meta?: {
        is_theme_logo?: boolean;
        theme_asset_index?: number;
    };
};
export type ContentSelectorSelectedItem = SelectedPage | SelectedFile | SelectedAsset | SelectedExternalLink;
export type BrowserSectionType = 'all' | 'favorites' | 'recent' | 'trash';
export type FolderFileWithFolderId = File & {
    folder_id?: string;
};
export type RecentFileWithFavoriteId = RecentFile & {
    favoriteId: string;
};
export declare function isPage(item: ContentSelectorSelectedItem): item is SelectedPage;
export declare function isFile(item: ContentSelectorSelectedItem): item is SelectedFile;
export declare function isAsset(item: ContentSelectorSelectedItem): item is SelectedAsset;
export declare function isExternalLink(item: ContentSelectorSelectedItem): item is SelectedExternalLink;
export type AppStateProperties = {
    appName: Ref<AppName | ''>;
    allowedContentTypes: Ref<FileContentTypeEnum[]>;
    activeSelectorType: Ref<SelectorType>;
    allowedIds: Ref<File['id'][]>;
    initialMetadataFilters: Ref<Record<string, any>>;
    allowedOriginalExtensions: Ref<string[] | undefined>;
    search: Ref<string>;
    searchMetadataFilters: Ref<Record<string, any>>;
    selectedItems: Ref<ContentSelectorSelectedItem[]>;
    selectedSection: Ref<BrowserSectionType>;
    selectedFiles: ComputedRef<SelectedFile[]>;
    selectedPages: ComputedRef<SelectedPage[]>;
    selectedAssets: ComputedRef<SelectedAsset[]>;
    selectedExternalLinks: ComputedRef<SelectedExternalLink[]>;
    sortedFavorites: ComputedRef<Favorite[]>;
    displayedFavorites: ComputedRef<(Favorite & {
        favoriteId: string;
    })[]>;
    displayedRecentFiles: ComputedRef<RecentFileWithFavoriteId[]>;
    showFilteredResults: ComputedRef<boolean>;
    displayedFiles: ComputedRef<SelectedFile[] | SelectedFolder[] | RecentFileWithFavoriteId[] | FolderFileWithFolderId[]>;
    activeFolderFolders: ComputedRef<FolderFolder[]>;
    activeFolderFiles: ComputedRef<FolderFile[]>;
    isAdmin: ComputedRef<boolean>;
    activeFolder: Ref<FolderRetrieve | null>;
    activeFile: Ref<FileRetrieve | null>;
    disableNoSharable: Ref<boolean>;
    recent: Ref<RecentFile[]>;
    favorites: Ref<Record<MiniPage['id'] | File['id'] | Folder['id'], Favorite>>;
    filteredItems: Ref<FolderFileWithFolderId[]>;
};
export type AppStore = AppStateProperties & {
    getThumbnailUrl: (file: Partial<File>) => string | null | undefined;
    setAppName: (appName: AppName) => void;
    resetSelectedItems: () => void;
    setSelectedItems: (items: ContentSelectorSelectedItem[], maxSelections?: number) => Promise<void>;
    setActiveSelectorType: (s?: SelectorType) => void;
    selectItem: (i: ContentSelectorSelectedItem) => void;
    selectAllFiles: (selection: SelectedFile[]) => void;
    setDisableNoSharable: (disable: boolean) => void;
    deselectAllFiles: (f: SelectedFile[] | Pick<FolderFile, 'id'>[]) => void;
    deselectFile: (f: SelectedFile | Pick<FolderFile, 'id'>) => void;
    deselectPage: (p: SelectedPage) => void;
    deselectAsset: (a: SelectedAsset) => void;
    deselectExternalLink: (l: SelectedExternalLink) => void;
    deselectItem: (item: ContentSelectorSelectedItem) => void;
    deselectFilePages: (f: Pick<FolderFile, 'id'>) => void;
    setAllowedIds: (ids: File['id'][]) => void;
    setSelectedSection: (section: BrowserSectionType) => void;
    setSearchQuery: (searchQuery: string) => void;
    setAllowedOriginalExtensions: (extensions: string[]) => void;
    setSearchMetadataFilters: (filters: Record<string, any>) => void;
    setFavorites: (favorites: Record<MiniPage['id'] | File['id'] | Folder['id'], Favorite>) => void;
    setRecentFiles: (recentFiles: RecentFile[]) => void;
    setFilteredItems: (filteredItems: FolderFileWithFolderId[]) => void;
    fetchSectionData: () => Promise<void>;
    setState: (newState: Partial<UnwrapNestedRefs<AppStore>>) => void;
    isItemDisabled: (item: SelectedFile | SelectedFolder | RecentFileWithFavoriteId | FolderFileWithFolderId) => boolean;
    setApiStore: (newApiStore: ApiStore) => void;
};
export default function (apiStore?: ApiStore): AppStore;
