import { LowLevelApi } from './LowLevelApi';
import { PitcherEvent, ApiOptions } from '../interfaces';
import * as modules from '@sdk/api/modules';
/**
 * Creates a high-level API instance and caches it. Reterns a new instance only if new options are provided.
 */
export declare function createHighLevelApi(options?: ApiOptions): {
    /**
     * Subscribe to a given event type by its key.
     *
     * @param {string} type - The event type to subscribe to.
     * @param {(payload: PitcherEvent) => void} callback - The callback function to handle the event.
     * @returns A Promise resolving to a cleanup function to unsubscribe from the event.     * @example
     *
     * @example
     * const unsubscribeFromSectionListUpdate = usePitcherApi().on('entered_fullscreen', (event: object) => {
     *   // handle event
     * })
     * // later
     * unsubscribeFromSectionListUpdate()
     */
    on: (type: string, callback: (payload: PitcherEvent) => void) => void;
    /**
     * Unsubscribe from a given event type by its key and the attached callback reference.
     * @param {string} type - The event type to unsubscribe from.
     * @param {(payload: PitcherEvent) => void} callback - The callback function reference to remove.
     *
     * @example
     * const callback = (event: object) => {
     *   // handle event
     * }
     * usePitcherApi().on('entered_fullscreen', callback)
     * // later
     * usePitcherApi().off('entered_fullscreen', callback)
     */
    off: (type: string, callback: (payload: PitcherEvent) => void) => void;
    /**
     * Make the entire CatalogIQ fullscreen.
     *
     * @example
     * usePitcherApi().enterFullscreen()
     */
    enterFullscreen: () => Promise<any>;
    /**
     * Exit fullscreen mode.
     *
     * @example
     * usePitcherApi().exitFullscreen()
     */
    exitFullscreen: () => Promise<any>;
    /**
     * Return is CatalogIQ in fullscreen.
     *
     * @example
     * usePitcherApi().isFullscreen()
     */
    isFullscreen: () => Promise<any>;
    /**
     * Log out the current user.
     *
     * @example
     * usePitcherApi().logout()
     */
    logout: () => Promise<any>;
    /**
     * Quit the current instance and go to the instance selection screen.
     *
     * @example
     * usePitcherApi().quitInstance()
     */
    quitInstance: () => Promise<any>;
    /**
     * Get the request types.
     *
     * @returns {Promise<any>}
     */
    getRequestTypes: () => Promise<any>;
    /**
     * Broadcast an event to CatalogIQ.
     * @param {PitcherEvent} event - The event to broadcast.
     *
     * @example
     * usePitcherApi()
     *   .broadcast({
     *     type: "canvas_updated",
     *     body: { context: { myContextProperty: 'test' } },
     *   })
     *   .then(function (result) {
     *     useUi().toast({
     *       message: "Canvas Populated.",
     *       type: "info",
     *     })
     *   })
     */
    broadcast: (event: PitcherEvent) => Promise<any>;
    /**
     * Subscribe to updates.
     *
     * @returns {Promise<void>}
     */
    subscribe: () => Promise<any>;
    /**
     * Unsubscribe from updates.
     *
     * @returns {Promise<void>}
     */
    unsubscribe: () => Promise<any>;
    open(payload?: import('../payload.types').OpenRequestPayload): Promise<string>;
    openExternalUrl(payload: import('../payload.types').OpenExternalUrlRequestPayload): Promise<void>;
    getEnv(): Promise<import('../interfaces').PitcherEnv>;
    updateMyUser(payload: {
        language?: import('../../main.lib').LanguageEnum | undefined;
    }): Promise<import('../../main.lib').User>;
    isOffline(): Promise<boolean>;
    getLanguages(): Promise<modules.Language[]>;
    getEvents(payload: Partial<import('../../main.lib').EventRequest>): Promise<import('../../main.lib').PaginatedData<import('../../main.lib').Event>>;
    createEvent(payload: import('../../main.lib').EventRequest): Promise<import('../../main.lib').Event>;
    updateEvent(payload: import('../../main.lib').PatchedEventRequest): Promise<import('../../main.lib').Event>;
    deleteEvent(payload: Partial<import('../../main.lib').Event>): Promise<void>;
    getCanvases(payload: import('../../main.lib').GetCanvasesParams & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../../main.lib').PaginatedData<import('../../main.lib').CanvasRetrieve>>;
    createCanvas(payload: Omit<import('../../main.lib').CanvasCreateRequest, "instance_id">): Promise<import('../../main.lib').CanvasRetrieve>;
    deleteCanvas(payload: {
        id: import('../../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../../main.lib').CanvasRetrieve>;
    updateCanvas(payload: import('../../main.lib').PatchedCanvasUpdateRequest & {
        id: import('../../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../../main.lib').Instance["id"];
        fields?: string;
    }): Promise<import('../../main.lib').CanvasRetrieve>;
    updateCanvasIndicators(payload: {
        indicators: Record<string, import('../../main.lib').CanvasIndicator>;
        id: import('../../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../../main.lib').Instance["id"];
    }): Promise<import('../../main.lib').CanvasRetrieve>;
    getCanvas(payload: {
        id: import('../../main.lib').CanvasRetrieve["id"];
        fields?: string;
    }): Promise<import('../../main.lib').CanvasRetrieve>;
    shareCanvas(payload: {
        id: import('../../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../../main.lib').SharedLink>;
    getCanvasRecommendedFiles(payload: {
        canvas_id: import('../../main.lib').CanvasRetrieve["id"];
        match?: ("tags" | "metadata")[];
    }): Promise<import('../../main.lib').CanvasRecommendedFiles>;
    getCanvasTheme(payload: {
        canvas_id: import('../../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../../main.lib').CanvasThemeRetrieve>;
    unassignCanvasTheme(payload: {
        canvas_id: import('../../main.lib').CanvasRetrieve["id"];
    }): Promise<void>;
    getFiles(payload: import('../payload.types').ListFilesPayload & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../../main.lib').PaginatedFileList>;
    getRecentFiles(payload?: import('../payload.types').GetRecentFilesPayload): Promise<import('../../main.lib').File[]>;
    downloadFile(payload: {
        file_id: import('../../main.lib').File["id"];
    }): Promise<null>;
    getAppConfig(payload: {
        app_name: string;
    }): Promise<Record<string, any>>;
    getFile(payload: {
        id?: import('../../main.lib').FileRetrieve["id"];
        file_id?: import('../../main.lib').FileRetrieve["id"];
    }): Promise<import('../../main.lib').FileRetrieve>;
    getFileRevisionData(payload: {
        file_id: import('../../main.lib').FileRetrieve["id"];
        revision_id: import('../../main.lib').FileRevision["id"];
    }): Promise<import('../../main.lib').FileRetrieve>;
    updateFile(payload: import('../../main.lib').FileUpdateRequest & {
        id: import('../../main.lib').File["id"];
    }): Promise<import('../../main.lib').FileRetrieve>;
    deleteFile(payload: {
        file_id: import('../../main.lib').File["id"];
    }): Promise<import('../../main.lib').File["id"]>;
    createFile(payload: Omit<import('../../main.lib').AllFileCreateRequest, "instance_id">): Promise<import('../../main.lib').FileRetrieve>;
    selectDeviceFile(): Promise<import('../../main.lib').DeviceFile>;
    getFileRevisions(payload: {
        id?: import('../../main.lib').FileRetrieve["id"];
        file_id?: import('../../main.lib').FileRetrieve["id"];
    }): Promise<import('../../main.lib').FileRevision[]>;
    search(payload: {
        query: string;
        includeExpired?: boolean;
    }): Promise<any>;
    getUsers(payload?: import('../../main.lib').GetUsersParams): Promise<import('../../main.lib').PaginatedData<import('../../main.lib').User>>;
    refreshServiceToken(payload?: import('../../main.lib').RefreshServiceTokenRequest): Promise<import('../../main.lib').RefreshServiceTokenResponse>;
    refreshAccessToken(): any;
    fetchDocumentInfo(payload: {
        fileId: import('../../main.lib').File["id"];
    }): Promise<{
        pageCount: number;
        [key: string]: unknown;
    }>;
    renderPageAsImage(payload: {
        fileId: import('../../main.lib').File["id"];
        documentId?: import('../../main.lib').File["id"];
        pageIndex: number;
        params: {
            width: number;
        } | {
            height: number;
        };
    }): Promise<ArrayBuffer>;
    toast(payload: {
        type: string;
        message: string;
    }): Promise<void>;
    query(payload: import('../payload.types').QueryPayload): Promise<any>;
    crmQuery(payload: import('../payload.types').CRMQueryPayload): Promise<any>;
    getFolders(payload: import('../payload.types').FolderListRequest): Promise<import('../../main.lib').PaginatedFolderList>;
    getFolder(payload?: {
        id: import('../../main.lib').FolderRetrieve["id"];
    }): Promise<import('../../main.lib').FolderRetrieve>;
    createFolder(payload: Omit<import('../../main.lib').FolderCreateRequest, "instance_id">): Promise<import('../../main.lib').FolderRetrieve>;
    updateFolder(payload: import('../../main.lib').FolderUpdateRequest & {
        id: import('../../main.lib').Folder["id"];
    }): Promise<import('../../main.lib').FolderRetrieve>;
    deleteFolder(payload: {
        folder_id: import('../../main.lib').FolderRetrieve["id"];
    }): Promise<void>;
    moveFolderItems(payload: {
        target_folder_id: import('../../main.lib').Folder["id"];
        items: {
            id: import('../../main.lib').File["id"] | import('../../main.lib').Folder["id"];
            type: "folder" | "file";
        }[];
    }): Promise<import('../../main.lib').FolderRetrieve>;
    getCoreFolders(payload: {
        instance_id: string;
        entity: import('../../main.lib').CoreFolderEntityType;
        parent_id?: string | null;
    }): Promise<import('../../main.lib').CoreFolderContentsRetrieve>;
    patchCoreFolder(id: string, payload: Partial<import('../../main.lib').CoreFolderRetrieve>): Promise<import('../../main.lib').CoreFolderContentsRetrieve>;
    getFavorites(payload?: import('../../main.lib').GetFavoritesParams): Promise<import('../../main.lib').PaginatedFavoriteList>;
    createFavorite(payload: import('../../main.lib').FavoriteCreateRequest): Promise<import('../../main.lib').Favorite>;
    deleteFavorite(payload: {
        favorite_id: import('../../main.lib').Favorite["id"];
    }): Promise<void>;
    notify(payload: import('../payload.types').NotificationPayload): Promise<void>;
    track(payload: {
        event_name: string;
        payload: any;
    }): Promise<any>;
    getInstanceMetadataTemplates(payload?: import('../payload.types').GetInstanceMetadataTemplatesPayload): Promise<import('../../main.lib').PaginatedMetadataTemplateList>;
    triggerNonFilesSync(): Promise<void>;
    submitUserFeedback(payload: import('../payload.types').SubmitUserFeedbackPayload): Promise<any>;
    close(): Promise<any>;
    openWebViewAlwaysOnTop(payload: import('../payload.types').OpenWebViewAlwaysOnTop): Promise<void>;
    share(payload: import('../payload.types').SharePayload): Promise<import('../payload.types').ShareResponse>;
    getThemes(payload: Partial<import('../../main.lib').CanvasThemeRetrieve>): Promise<import('../../main.lib').CanvasThemeRetrieve[]>;
    assignCanvasTheme(payload: {
        canvas_id: import('../../main.lib').CanvasRetrieve["id"];
        theme_id: import('../../main.lib').CanvasThemeRetrieve["id"];
    }): Promise<{
        canvas_id: import('../../main.lib').CanvasRetrieve["id"];
        theme_id: import('../../main.lib').CanvasThemeRetrieve["id"];
    }>;
    API: LowLevelApi;
};
