import { File, Folder, FolderRetrieve, FolderCreateRequest, FolderUpdateRequest, PaginatedFolderList } from '../../../../types/openapi';
import { FolderListRequest } from '../../payload.types';
/**
 * Retrieves a list of folders.
 * @param payload - The payload containing the search, ordering, filters, fields, name, page, and page_size.
 * @returns A promise that resolves to the list of folders.
 */
export declare function getFolders(payload: FolderListRequest): Promise<PaginatedFolderList>;
/**
 * Retrieves a folder by its ID.
 * @param payload - An object containing the folder ID.
 * @param payload.id - The ID of the folder to retrieve. Defaults to 'root'.
 * @returns A promise that resolves to the retrieved folder.
 */
export declare function getFolder(payload?: {
    id: FolderRetrieve['id'];
}): Promise<FolderRetrieve>;
/**
 * Creates a new folder.
 * @param payload - The folder creation request payload, excluding the instance_id.
 * @returns A promise that resolves to the created folder.
 */
export declare function createFolder(payload: Omit<FolderCreateRequest, 'instance_id'>): Promise<FolderRetrieve>;
type UpdateFolderPayload = FolderUpdateRequest & {
    id: Folder['id'];
};
/**
 * Updates an existing folder.
 * @param payload - The folder update payload, including the folder ID and update data.
 * @returns A promise that resolves to the updated folder.
 */
export declare function updateFolder(payload: UpdateFolderPayload): Promise<FolderRetrieve>;
/**
 * Deletes a folder.
 * @param payload - An object containing the ID of the folder to delete.
 * @param payload.folder_id - The ID of the folder to delete.
 * @returns A promise that resolves when the folder is deleted.
 */
export declare function deleteFolder(payload: {
    folder_id: FolderRetrieve['id'];
}): Promise<void>;
/**
 * Moves items (files or folders) to a target folder.
 * @param payload - The payload containing the target folder ID and items to move.
 * @param payload.target_folder_id - The ID of the target folder.
 * @param payload.items - An array of items to move, each with an ID and type.
 * @returns A promise that resolves to the updated target folder.
 */
export declare function moveFolderItems(payload: {
    target_folder_id: Folder['id'];
    items: {
        id: File['id'] | Folder['id'];
        type: 'folder' | 'file';
    }[];
}): Promise<FolderRetrieve>;
export {};
